'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extensions = exports.Find = undefined;

var _elliptical = require('elliptical');

var _laconaPhrases = require('lacona-phrases');

var _laconaApi = require('lacona-api');

var _child_process = require('child_process');

/** @jsx createElement */
var Find = exports.Find = {
  extends: [_laconaPhrases.Command],

  execute: function execute(result) {
    function reveal(path) {
      (0, _laconaApi.runApplescript)({
        script: '\n        tell application "Finder"\n          reveal POSIX file "' + path + '" as text\n          activate\n        end tell\n        '
      });
    }

    var callback = function callback(err, stdout, stderr) {
      console.log(stdout);
      var path = stdout.substring(0, stdout.length - 1);
      reveal(path);
    };

    if (result.discovered.app) {
      var path = result.discovered.app.path;
      reveal(path);
    } else {
      var path = result.discovered.path;
      reveal(path);
    }
  },
  describe: function describe() {
    return (0, _elliptical.createElement)(
      'sequence',
      null,
      (0, _elliptical.createElement)('literal', { text: 'Find ' }),
      (0, _elliptical.createElement)(
        'choice',
        { id: 'discovered' },
        (0, _elliptical.createElement)(_laconaPhrases.Application, { id: 'app' }),
        (0, _elliptical.createElement)(_laconaPhrases.Directory, { id: 'path' }),
        (0, _elliptical.createElement)(_laconaPhrases.File, { id: 'path' })
      )
    );
  }
};

var extensions = exports.extensions = [Find];